@@ -31,14 +31,14 @@ class RequestsProKeywords(RequestsLibrary):
         # Map the lowering function to all column names
         # test_cases_df.columns = map(str.lower, test_cases_df.columns)
 
-        selected_api_df = test_cases_df.loc[test_cases_df['Test_Name'] == api_name].copy()
-        selected_api_df = selected_api_df.loc[selected_api_df['TBE'] == 'YES']
+        selected_api_df = test_cases_df.loc[test_cases_df['test_name'] == api_name].copy()
+        selected_api_df = selected_api_df.loc[selected_api_df['tbe'] == 'YES']
         selected_api_df = selected_api_df.reset_index(drop=True)
         logger.debug('API Name      :' + api_name)
         logger.info('Step-01: End   - Read and filter test data sheet based on API_NAME')
 
         logger.info('Step-02: Start - Identify the request type')
-        request_type = str(selected_api_df['Request_Type'][0])
+        request_type = str(selected_api_df['request_type'][0])
         logger.info('Step-02: End   - Identify the request type')
 
         logger.info('Step-03: Start - Assign default values to None')
@@ -65,7 +65,7 @@ class RequestsProKeywords(RequestsLibrary):
         # Unique identifier for creating a session
         alias = str(api_name)
 
-        uri = str(selected_api_df['URI'][0])
+        uri = str(selected_api_df['uri'][0])
         logger.info('Step-05: End   - Identify uri')
 
         logger.info('Step-06: Start - Create the parameter and assign to params')
@@ -92,7 +92,8 @@ class RequestsProKeywords(RequestsLibrary):
         if pd.isna(selected_api_df.loc[0, 'data']):
             data = None
         else:
-            with open(test_input_path + api_name + '/' + api_name + '.JSON') as f:
+            file_name = str(selected_api_df['data'][0])
+            with open(test_input_path + api_name + '/' + file_name + '.JSON') as f:
                 data = json.load(f)
 
         # Check if authorization is required
@@ -160,6 +161,19 @@ class RequestsProKeywords(RequestsLibrary):
             # Trigger Get method
             response = super(RequestsLibrary, self).get_request(alias=alias, uri=uri, headers=headers, json=data,
                                                                 params=params, allow_redirects=None, timeout=timeout)
+        elif request_type == 'PUT':
+
+            # Response with status code, response content and api name will be returned as data frame
+            # Create Session
+            super(RequestsLibrary, self).create_session(alias=alias, url=base_url, headers=headers, cookies=cookies,
+                                                        auth=auth, timeout=timeout, proxies=proxies, verify=verify,
+                                                        debug=debug, max_retries=max_retries,
+                                                        backoff_factor=backoff_factor,
+                                                        disable_warnings=disable_warnings)
+            # Trigger Get method
+            response = super(RequestsLibrary, self).put_request(alias=alias, uri=uri, data=data, json=json_data,
+                                                                params=params, files=files, headers=headers,
+                                                                allow_redirects=None, timeout=timeout)
         else:
             # Create Session
             super(RequestsLibrary, self).create_session(alias=alias, url=base_url, headers=headers, cookies=cookies,
@@ -199,10 +213,10 @@ class RequestsProKeywords(RequestsLibrary):
         logger.info('*************************************************************************************************')
         logger.info('Reading API Test Data File and return the APIs to be executed')
         logger.info('*************************************************************************************************')
-        logger.info('Step-01: Start - Read and filter based on TBE')
+        logger.info('Step-01: Start - Read and filter based on tbe')
         test_cases_df = pd.read_csv(str(test_data_full_path))
-        test_cases_df = test_cases_df.loc[test_cases_df['TBE'] == 'YES']
+        test_cases_df = test_cases_df.loc[test_cases_df['tbe'] == 'YES']
         test_cases_dict = test_cases_df.to_dict('records')
-        logger.info('Step-01: End   - Read and filter based on TBE')
+        logger.info('Step-01: End   - Read and filter based on tbe')
         logger.info('*************************************************************************************************')
         return test_cases_dict
